@@ -77,7 +77,7 @@ fn generate_changelog() -> Result<()> {
 		tag_pattern:              None,
 		skip_tags:                None,
 		ignore_tags:              None,
-		date_order:               None,
+		topo_order:               None,
 		sort_commits:             None,
 		link_parsers:             Some(vec![
 			LinkParser {
