@@ -1,20 +1,20 @@
 use clap::{
-	AppSettings,
-	ArgEnum,
+	ArgAction,
 	Parser,
+	ValueEnum,
 };
 use git_cliff_core::DEFAULT_CONFIG;
 use glob::Pattern;
 use std::path::PathBuf;
 
-#[derive(Debug, Clone, Copy, ArgEnum)]
+#[derive(Debug, Clone, Copy, ValueEnum)]
 pub enum Strip {
 	Header,
 	Footer,
 	All,
 }
 
-#[derive(Debug, Clone, Copy, PartialEq, Eq, ArgEnum)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, ValueEnum)]
 pub enum Sort {
 	Oldest,
 	Newest,
@@ -22,68 +22,93 @@ pub enum Sort {
 
 /// Command-line arguments to parse.
 #[derive(Debug, Parser)]
-#[clap(
+#[command(
     version,
-    author,
+    author = clap::crate_authors!("\n"),
     about,
-    global_setting = AppSettings::DeriveDisplayOrder,
     rename_all_env = "screaming-snake",
-    next_help_heading = Some("OPTIONS"),
+	help_template = "\
+{before-help}{name} {version}
+{author-with-newline}{about-with-newline}
+{usage-heading}
+  {usage}
+
+{all-args}{after-help}
+",
     override_usage = "git-cliff [FLAGS] [OPTIONS] [--] [RANGE]",
-    mut_arg("help", |arg| arg.help("Prints help information").help_heading("FLAGS")),
-    mut_arg("version", |arg| arg.help("Prints version information").help_heading("FLAGS"))
+    next_help_heading = Some("OPTIONS"),
+	disable_help_flag = true,
+	disable_version_flag = true,
 )]
 pub struct Opt {
+	#[arg(
+		short,
+		long,
+		action = ArgAction::Help,
+		global = true,
+		help = "Prints help information",
+		help_heading = "FLAGS"
+	)]
+	pub help:         Option<bool>,
+	#[arg(
+		short = 'V',
+		long,
+		action = ArgAction::Version,
+		global = true,
+		help = "Prints version information",
+		help_heading = "FLAGS"
+	)]
+	pub version:      Option<bool>,
 	/// Increases the logging verbosity.
-	#[clap(short, long, parse(from_occurrences), alias = "debug", help_heading = Some("FLAGS"))]
+	#[arg(short, long, action = ArgAction::Count, alias = "debug", help_heading = Some("FLAGS"))]
 	pub verbose:      u8,
 	/// Sets the configuration file.
-	#[clap(short, long, env = "GIT_CLIFF_CONFIG", value_name = "PATH", default_value = DEFAULT_CONFIG)]
+	#[arg(short, long, env = "GIT_CLIFF_CONFIG", value_name = "PATH", default_value = DEFAULT_CONFIG)]
 	pub config:       PathBuf,
 	/// Sets the working directory.
-	#[clap(short, long, env = "GIT_CLIFF_WORKDIR", value_name = "PATH")]
+	#[arg(short, long, env = "GIT_CLIFF_WORKDIR", value_name = "PATH")]
 	pub workdir:      Option<PathBuf>,
 	/// Sets the git repository.
-	#[clap(
+	#[arg(
 		short,
 		long,
 		env = "GIT_CLIFF_REPOSITORY",
 		value_name = "PATH",
-		multiple_values = true
+		num_args(1..)
 	)]
 	pub repository:   Option<Vec<PathBuf>>,
 	/// Sets the path to include related commits.
-	#[clap(
+	#[arg(
 		long,
 		env = "GIT_CLIFF_INCLUDE_PATH",
 		value_name = "PATTERN",
-		multiple_values = true
+		num_args(1..)
 	)]
 	pub include_path: Option<Vec<Pattern>>,
 	/// Sets the path to exclude related commits.
-	#[clap(
+	#[arg(
 		long,
 		env = "GIT_CLIFF_EXCLUDE_PATH",
 		value_name = "PATTERN",
-		multiple_values = true
+		num_args(1..)
 	)]
 	pub exclude_path: Option<Vec<Pattern>>,
 	/// Sets custom commit messages to include in the changelog.
-	#[clap(
+	#[arg(
 		long,
 		env = "GIT_CLIFF_WITH_COMMIT",
 		value_name = "MSG",
-		multiple_values = true
+		num_args(1..)
 	)]
 	pub with_commit:  Option<Vec<String>>,
 	/// Prepends entries to the given changelog file.
-	#[clap(short, long, env = "GIT_CLIFF_PREPEND", value_name = "PATH")]
+	#[arg(short, long, env = "GIT_CLIFF_PREPEND", value_name = "PATH")]
 	pub prepend:      Option<PathBuf>,
 	/// Writes output to the given file.
-	#[clap(short, long, env = "GIT_CLIFF_OUTPUT", value_name = "PATH")]
+	#[arg(short, long, env = "GIT_CLIFF_OUTPUT", value_name = "PATH")]
 	pub output:       Option<PathBuf>,
 	/// Sets the tag for the latest version.
-	#[clap(
+	#[arg(
 		short,
 		long,
 		env = "GIT_CLIFF_TAG",
@@ -92,7 +117,7 @@ pub struct Opt {
 	)]
 	pub tag:          Option<String>,
 	/// Sets the template for the changelog body.
-	#[clap(
+	#[arg(
 		short,
 		long,
 		env = "GIT_CLIFF_TEMPLATE",
@@ -101,34 +126,45 @@ pub struct Opt {
 	)]
 	pub body:         Option<String>,
 	/// Writes the default configuration file to cliff.toml
-	#[clap(short, long, help_heading = Some("FLAGS"))]
+	#[arg(short, long, help_heading = Some("FLAGS"))]
 	pub init:         bool,
 	/// Processes the commits starting from the latest tag.
-	#[clap(short, long, help_heading = Some("FLAGS"))]
+	#[arg(short, long, help_heading = Some("FLAGS"))]
 	pub latest:       bool,
 	/// Processes the commits that belong to the current tag.
-	#[clap(long, help_heading = Some("FLAGS"))]
+	#[arg(long, help_heading = Some("FLAGS"))]
 	pub current:      bool,
 	/// Processes the commits that do not belong to a tag.
-	#[clap(short, long, help_heading = Some("FLAGS"))]
+	#[arg(short, long, help_heading = Some("FLAGS"))]
 	pub unreleased:   bool,
 	/// Sorts the tags topologically.
-	#[clap(long, help_heading = Some("FLAGS"))]
+	#[arg(long, help_heading = Some("FLAGS"))]
 	pub topo_order:   bool,
 	/// Prints changelog context as JSON.
-	#[clap(long, help_heading = Some("FLAGS"))]
+	#[arg(long, help_heading = Some("FLAGS"))]
 	pub context:      bool,
 	/// Strips the given parts from the changelog.
-	#[clap(short, long, value_name = "PART", arg_enum)]
+	#[arg(short, long, value_name = "PART", value_enum)]
 	pub strip:        Option<Strip>,
 	/// Sets sorting of the commits inside sections.
-	#[clap(
+	#[arg(
 		long,
-		arg_enum,
+		value_enum,
 		default_value_t = Sort::Oldest
 	)]
 	pub sort:         Sort,
 	/// Sets the commit range to process.
-	#[clap(value_name = "RANGE", help_heading = Some("ARGS"))]
+	#[arg(value_name = "RANGE", help_heading = Some("ARGS"))]
 	pub range:        Option<String>,
 }
+
+#[cfg(test)]
+mod tests {
+	use super::*;
+	use clap::CommandFactory;
+
+	#[test]
+	fn verify_cli() {
+		Opt::command().debug_assert()
+	}
+}
